@@ -10,45 +10,51 @@
 #'
 #' @param geography A character string denoting the level of census geography
 #'   whose ADIs and ADI-3s you'd like to obtain. Must be one of `c("state",
-#'   "county", "tract", "block group", "zcta")`. Required.
+#'   "county", "tract", "block group", "zcta")` (`"zip code tabulation area"`
+#'   will be changed to `"zcta"`).
 #' @param state A character string specifying states whose ADI and ADI-3 data is
 #'   desired. Defaults to `NULL`. Can contain full state names, two-letter state
 #'   abbreviations, or a two-digit FIPS code/GEOID (must be a vector of strings,
 #'   so use quotation marks and leading zeros if necessary). Must be left as
-#'   `NULL` if using the `geoid` or `zcta` parameter.
+#'   `NULL` if using the `geoid`.
+#'
+#'   If `geography = "zcta"` and `year` is earlier than 2020, this argument can
+#'   be used to only include ZCTAs associated with specific states, as
+#'   determined by the US Census bureau. If year is 2020 or later, this argument
+#'   will be ignored with a [warning].
 #' @param county A vector of character strings specifying the counties whose ADI
 #'   and ADI-3 data you're requesting. Defaults to `NULL`. If not `NULL`, the
 #'   `state` parameter must have a length of 1. County names and three-digit
 #'   FIPS codes are accepted (must contain strings, so use quotation marks and
-#'   leading zeros if necessary). Must be blank if using the `geoid` parameter.
+#'   leading zeros if necessary). Must be `NULL` if using the `geoid` parameter
+#'   or if `geography = "zcta"`.
 #' @param geoid A character vector of GEOIDs (use quotation marks and leading
 #'   zeros). Defaults to `NULL`. Must be blank if `state`, `county`, or `zcta`
 #'   is used. Can contain different levels of geography (see details).
 #' @param zcta A character vector of ZCTAs or the leading digit(s) of ZCTAs (use
 #'   quotation marks and leading zeros). Defaults to `NULL`. Must be blank if
-#'   `state`, `county`, or `geoid` is used.
+#'   `county` or `geoid` is used.
 #'
 #'   Strings under 5 digits long will yield all ZCTAs that begin with those
 #'   digits.
 #'
 #'   Requires that `geography = "zcta"`. If `geography = "zcta"` and `zcta =
-#'   NULL`, all ZCTAs in the US will be used.
+#'   NULL`, all ZCTAs in the 50 states plus DC and Puerto Rico will be used.
 #' @param year Single integer specifying the year of US Census data to use.
 #' @param dataset The data set used to calculate ADIs and ADI-3s. Must be one of
 #'   `c("acs5", "acs3", "acs1", "decennial")`, denoting the 5-, 3-, and 1-year
 #'   ACS along with the decennial census. Defaults to `"acs5"`.
 #'
-#'   When `dataset = "decennial"`, `year` must be in `c(1990, 2000, 2010)`.
+#'   When `dataset = "decennial"`, `year` must be in `c(2000, 2010, 2020)`.
 #'
-#'   The 2010 decennial census did not include the long-form questionnaire used
-#'   in the 1990 and 2000 censuses, so this function uses the 5-year estimates
-#'   from the 2010 ACS to supply the data not included in the 2010 decennial
-#'   census. In fact, the only 2010 decennial variables used are H003002,
-#'   H014002, P020002, and P020008.
+#'   The 2010 and 2020 decennial censuses did not include the long-form
+#'   questionnaire used in the 1990 and 2000 censuses, so this function uses the
+#'   5-year estimates from the 2010/2020 ACS to supply the data not included in
+#'   the decennial censuses.
 #'
 #'   Important: data are not always available depending on the level of
-#'   geography and data set chosen. See
-#'   <https://www.census.gov/programs-surveys/acs/guidance/estimates.html>.
+#'   geography and data set chosen. See [`dataset_year_geography_availability`]
+#'   and <https://www.census.gov/programs-surveys/acs/guidance/estimates.html>.
 #' @param geometry Logical value indicating whether or not shapefile data should
 #'   be included in the result, making the result an [`sf`][sf::sf] object
 #'   instead of a plain [`tibble`][tibble::tibble]. Defaults to `FALSE`.
@@ -72,7 +78,9 @@
 #' @param raw_data_only Logical, indicating whether or not to skip calculation
 #'   of the ADI and ADI-3 and only return the census variables. Defaults to
 #'   `FALSE`.
-#' @param seed Passed to [calculate_adi()].
+#' @param evaluator A function that will evaluate the calls to the tidycensus
+#'   functions. Defaults to [`purrr::insistently`]`(`[`eval`]`, rate =
+#'   `[purrr::rate_delay()]`, quiet = FALSE)`.
 #' @param ... Additional arguments to be passed onto [tidycensus::get_acs()] or
 #'   [tidycensus::get_decennial()]. These must all be named. Must not match any
 #'   of the `tidycensus` formal arguments that `sociome` needs to set
@@ -85,7 +93,9 @@
 #'   according to the the value of `geography`). This enables the user to
 #'   somewhat customize the shapefile data obtained.
 #'
-#' @section Reference area: **The concept of "reference area" is important to
+#' @section Reference area:
+#'
+#'   **The concept of "reference area" is important to
 #'   understand when using this function.** The algorithm that produced the
 #'   original ADIs employs factor analysis. As a result, the ADI is a relative
 #'   measure; the ADI of a particular location is dynamic, varying depending on
@@ -126,11 +136,11 @@
 #'   in many missing values.
 #'
 #'   Imputation is attempted via [`mice::mice`]`(m = 1, maxit = 50, method =
-#'   "pmm", seed = seed)`. If imputation is unsuccessful, an error is thrown,
-#'   but the dataset of indicators on which imputation was unsuccessful is
-#'   available via [rlang::last_error()]`$adi_indicators` and the raw census
-#'   data are available via [rlang::last_error()]`$adi_raw_data`. The former
-#'   excludes areas with zero households, but the latter includes them.
+#'   "pmm")`. If imputation is unsuccessful, an error is thrown, but the dataset
+#'   of indicators on which imputation was unsuccessful is available via
+#'   [rlang::last_error()]`$adi_indicators` and the raw census data are
+#'   available via [rlang::last_error()]`$adi_raw_data`. The former excludes
+#'   areas with zero households, but the latter includes them.
 #'
 #'   One of the indicators of both ADI and the Financial Strength component of
 #'   ADI-3 is median family income, but methodological issues with the 2015 and
@@ -158,6 +168,9 @@
 #'   <https://www.census.gov/programs-surveys/acs/guidance/estimates.html> for
 #'   details.
 #'
+#' @seealso [`dataset_year_geography_availability`] for usable combinations of
+#'   `geography`, `year`, and `dataset`.
+#'
 #' @examples
 #' \dontrun{
 #' # Wrapped in \dontrun{} because all these examples take >5 seconds
@@ -221,7 +234,8 @@
 #'   `geometry = TRUE` is specified, an [`sf`][sf::sf].
 #' @importFrom rlang .data
 #' @export
-get_adi <- function(geography,
+get_adi <- function(geography = c("state", "county", "tract", "block group",
+                                  "zcta", "zip code tabulation area"),
                     state           = NULL,
                     county          = NULL,
                     geoid           = NULL,
@@ -233,144 +247,32 @@ get_adi <- function(geography,
                     raw_data_only   = FALSE,
                     cache_tables    = TRUE,
                     key             = NULL,
-                    seed            = NA,
+                    evaluator =
+                      purrr::insistently(
+                        eval,
+                        rate = purrr::rate_delay(),
+                        quiet = FALSE
+                      ),
                     ...) {
-  
-  geography <- validate_geography(geography)
+  geography <- validate_geography(match.arg(geography))
   year      <- validate_year(year)
-  dataset   <- validate_dataset(dataset, year, geography)
-  
+  dataset   <- validate_dataset(match.arg(dataset), year, geography)
+
   # Any given call to get_adi() necessitates one or more calls to
   # tidycensus::get_acs() and/or tidycensus::get_decennial(). The following
   # creates the skeletons of these calls, irrespective of location (i.e.,
   # state/county/geoid/zcta)
   partial_tidycensus_calls <-
-    switch(
-      dataset,
-      decennial = 
-        
-        # The 2010 decennial census did not gather the same detailed data that
-        # the 2000 and 1990 censuses did (i.e., the 2010 census has no SF3), so
-        # its gaps are filled with the 2010 5-year ACS estimates (in reality,
-        # only a few data points are available from the 2010 decennial census
-        # and most of the data is taken from the ACS)
-        if (year == 2010) {
-          
-          list(
-            get_decennial =
-              tidycensus_call(
-                .fn = "get_decennial",
-                geography = geography,
-                variables = 
-                  sociome::decennial_vars[
-                    sociome::decennial_vars$year == 2010,
-                    "variable",
-                    drop = TRUE
-                  ],
-                table = NULL,
-                cache_table = cache_tables,
-                year = 2010,
-                sumfile = "sf1",
-                geometry = geometry,
-                output = "tidy",
-                keep_geo_vars = FALSE,
-                summary_var = NULL,
-                key = key,
-                ...
-              ),
-            get_acs =
-              tidycensus_call(
-                .fn = "get_acs",
-                geography = geography,
-                variables =
-                  sociome::acs_vars$variable[sociome::acs_vars$dec2010],
-                table = NULL,
-                cache_table = cache_tables,
-                year = 2010,
-                output = "tidy",
-                geometry = geometry,
-                keep_geo_vars = FALSE,
-                summary_var = NULL,
-                key = key,
-                survey = "acs5",
-                ...
-              )
-          )
-          
-        } else {
-          
-          # Everything prior to pmap() creates 2 by 2 tibble with column
-          # sumfile = c("sf1", "sf3") and list column "variables" that
-          # contains the corresponding SF1 and SF3 variables.
-          sociome::decennial_vars[sociome::decennial_vars$year == year, ] %>% 
-            eval(expr = quote(split(variable, f = sumfile))) %>% 
-            tibble::enframe(name = "sumfile", value = "variables") %>% 
-            purrr::pmap(
-              .f = tidycensus_call,
-              .fn = "get_decennial",
-              geography = geography,
-              table = NULL, 
-              cache_table = cache_tables,
-              year = year,
-              geometry = geometry,
-              output = "tidy",
-              keep_geo_vars = FALSE,
-              summary_var = NULL,
-              key = key,
-              ...
-            )
-        },
-      
-      # i.e., if ACS data requested instead of decennial
-      {
-        
-        variables_set <- 
-          if (year >= 2011) {
-            if (any(2015:2016 == year) && geography == "block group") {
-              "set2"
-            } else if (year == 2011 && dataset == "acs5") {
-              "set3"
-            } else {
-              "set1"
-            }
-          } else if (year == 2010) {
-            if (dataset == "acs5") {
-              "set5"
-            } else {
-              "set4"
-            }
-          } else if (dataset == "acs1" && year >= 2008) {
-            "set6"
-          } else {
-            "set7"
-          }
-        
-        list(
-          get_acs =
-            tidycensus_call(
-              .fn = "get_acs",
-              geography = geography,
-              variables = 
-                sociome::acs_vars[
-                  sociome::acs_vars[[variables_set]],
-                  "variable",
-                  drop = TRUE
-                ],
-              table = NULL,
-              cache_table = cache_tables,
-              year = year,
-              output = "tidy",
-              geometry = geometry,
-              keep_geo_vars = FALSE,
-              summary_var = NULL,
-              key = key,
-              survey = dataset,
-              ...
-            )
-        )
-      }
+    make_partial_tidycensus_calls(
+      dataset = dataset,
+      year = year,
+      geography = geography,
+      cache_tables = cache_tables,
+      geometry = geometry,
+      key = key,
+      ...
     )
-  
+
   raw_data <-
     get_tidycensus(
       geography = geography,
@@ -381,26 +283,13 @@ get_adi <- function(geography,
       year = year,
       dataset = dataset,
       partial_tidycensus_calls = partial_tidycensus_calls,
-      geometry = geometry
+      geometry = geometry,
+      evaluator = evaluator
     )
-  
+
   if (raw_data_only) {
     raw_data
   } else {
-    calculate_adi(raw_data, keep_indicators = keep_indicators, seed = seed)
+    calculate_adi(raw_data, keep_indicators = keep_indicators)
   }
 }
-
-
-# 
-# exec_tidycensus <- function(state = NULL, county = NULL, ...) {
-#   if (!is.null(state)) {
-#     message("\nState: ", paste(state, collapse = ", "))
-#     if (!is.null(county)) {
-#       message("\nCounty: ", paste(county, collapse = ", "))
-#     }
-#   }
-#   exec_insistently(..., state = state, county = county)
-# }
-
-
